[Python-checkins] cpython: Further increase tolerance for slow buildbots

nick.coghlan python-checkins at python.org
Mon Dec 23 09:17:33 CET 2013


http://hg.python.org/cpython/rev/64786a88c641
changeset:   88147:64786a88c641
user:        Nick Coghlan <ncoghlan at gmail.com>
date:        Mon Dec 23 18:17:20 2013 +1000
summary:
  Further increase tolerance for slow buildbots

files:
  Lib/test/test_multiprocessing_main_handling.py |  4 ++--
  1 files changed, 2 insertions(+), 2 deletions(-)


diff --git a/Lib/test/test_multiprocessing_main_handling.py b/Lib/test/test_multiprocessing_main_handling.py
--- a/Lib/test/test_multiprocessing_main_handling.py
+++ b/Lib/test/test_multiprocessing_main_handling.py
@@ -53,7 +53,7 @@
     p = Pool(5)
     results = []
     p.map_async(f, [1, 2, 3], callback=results.extend)
-    deadline = time.time() + 5 # up to 5 s to report the results
+    deadline = time.time() + 10 # up to 10 s to report the results
     while not results:
         time.sleep(0.05)
         if time.time() > deadline:
@@ -81,7 +81,7 @@
 p = Pool(5)
 results = []
 p.map_async(int, [1, 4, 9], callback=results.extend)
-deadline = time.time() + 5 # up to 5 s to report the results
+deadline = time.time() + 10 # up to 10 s to report the results
 while not results:
     time.sleep(0.05)
     if time.time() > deadline:

-- 
Repository URL: http://hg.python.org/cpython


More information about the Python-checkins mailing list